marine_mammals: Admission and release data for 300 marine mammals, collected...

Description Usage Format Source

Description

Admission and release data for 300 marine mammals, collected by the Marine Mammal Rescue (MMR) organization and scraped from https://mmrpatients.org/ on 2021-07-01

Usage

1

Format

A dataframe with 300 rows and 13 variables:

id

indexing id

patient_id

id assigned to the animal by MMR

name

name of the animal

sex

sex of the animal

collection_site

location the animal was rescued from

reason_for_admit

reasons for animal admission, multiple reasons separate by semi-colon

admit_date

date the animal was admitted to MMR

admit_weight

weight of the animal upon admission, in kg

release_date

date of the animal's release

release_site

location of the animal's release

release_weight

weight of the animal upon release, in kg

transfer_date

date the animal was transferred to another facility. NA means no transfer.

url

link to the animal's page on the MMR website, contains additional data

https://mmrpatients.org/


kierisi/marinemammalrescue documentation built on Dec. 21, 2021, 6:40 a.m.